# Results API

API documentation for the PanelResults class and related functionality.

---

## PanelResults

::: panelbox.core.results.PanelResults
    options:
      show_root_heading: true
      show_source: false
      heading_level: 3
      members:
        - params
        - std_errors
        - tstats
        - pvalues
        - conf_int
        - rsquared
        - rsquared_within
        - rsquared_between
        - rsquared_overall
        - rsquared_adj
        - fstat
        - fstat_pvalue
        - nobs
        - n_entities
        - n_periods
        - df_model
        - df_resid
        - summary
        - to_latex
        - hansen_j
        - sargan
        - ar1_test
        - ar2_test
        - diff_hansen
        - instrument_ratio
